@@ -26,4 +26,8 @@ def load_trigram_file(f):
             l = line.strip().split("\t")
             words = l[0].split(" ")
             trgs.append([Trigram(word=words[-1],word_i_minus_one=words[1],word_i_minus_two=words[0],count=int(l[1]))])
-    rigram.objects.bulk_create(trgs)
+            if len(trgs) > 100000:
+                Trigram.objects.bulk_create(trgs)
+                trgs = []
+    if trgs != []:
+        Trigram.objects.bulk_create(trgs)
